summaryrefslogtreecommitdiff
path: root/sw/source/core/layout/findfrm.cxx
diff options
context:
space:
mode:
authorVladimir Glazounov <vg@openoffice.org>2008-02-12 12:25:57 +0000
committerVladimir Glazounov <vg@openoffice.org>2008-02-12 12:25:57 +0000
commite04553b3d0da728220238da76066f3b93fae05d8 (patch)
treee3295b68fd4f8274dda49ae00c7612ad6ef1c5f1 /sw/source/core/layout/findfrm.cxx
parent498c1fb37b912ea5a8190cf4bb8fcf3940889a8b (diff)
INTEGRATION: CWS sw8u10stopper_SRC680 (1.45.152); FILE MERGED
2008/01/31 15:28:29 ama 1.45.152.1: Fix #i85619#: New tables with merged cells in repeated header
Diffstat (limited to 'sw/source/core/layout/findfrm.cxx')
-rw-r--r--sw/source/core/layout/findfrm.cxx11
1 files changed, 7 insertions, 4 deletions
diff --git a/sw/source/core/layout/findfrm.cxx b/sw/source/core/layout/findfrm.cxx
index 3dfd401687dd..eb501a3b4acc 100644
--- a/sw/source/core/layout/findfrm.cxx
+++ b/sw/source/core/layout/findfrm.cxx
@@ -4,9 +4,9 @@
*
* $RCSfile: findfrm.cxx,v $
*
- * $Revision: 1.45 $
+ * $Revision: 1.46 $
*
- * last change: $Author: ihi $ $Date: 2007-10-15 17:33:05 $
+ * last change: $Author: vg $ $Date: 2008-02-12 13:25:57 $
*
* The Contents of this file are made available subject to
* the terms of GNU Lesser General Public License Version 2.1.
@@ -1657,6 +1657,8 @@ const SwCellFrm& SwCellFrm::FindStartEndOfRowSpanCell( bool bStart, bool bCurren
if ( bCurrentTableOnly )
{
const SwFrm* pCurrentRow = GetUpper();
+ const bool bDoNotEnterHeadline = bStart && pTableFrm->IsFollow() &&
+ !pTableFrm->IsInHeadline( *pCurrentRow );
// check how many rows we are allowed to go up or down until we reach the end of
// the current table frame:
@@ -1665,8 +1667,9 @@ const SwCellFrm& SwCellFrm::FindStartEndOfRowSpanCell( bool bStart, bool bCurren
{
if ( bStart )
{
- // do not accept a repeated headline:
- if ( pTableFrm->IsFollow() && pTableFrm->IsInHeadline( *pCurrentRow->GetPrev() ) )
+ // do not enter a repeated headline:
+ if ( bDoNotEnterHeadline && pTableFrm->IsFollow() &&
+ pTableFrm->IsInHeadline( *pCurrentRow->GetPrev() ) )
break;
pCurrentRow = pCurrentRow->GetPrev();